@@ -19,6 +19,7 @@ class LoadCase():
                 self_weight = [self_weight_active, self_weight_factor_x, self_weight_factor_y, self_weight_factor_z]
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         '''
 
         # Client model | Load Case
@@ -78,7 +79,7 @@ class LoadCase():
             to_solve: bool = True,
             analysis_settings_no: int = 1,
             action_category=ActionCategoryType.ACTION_CATEGORY_PERMANENT_G,
-            self_weight=[True, 0.0, 0.0, 10.0],
+            self_weight: list =[True, 0.0, 0.0, 10.0],
             comment: str = 'Comment',
             params: dict = None,
             model = Model):
@@ -87,9 +88,8 @@ class LoadCase():
             no (int): Load Case Tag
             name (str): Load Case Name
             to_solve (bool): Enable/Disbale Load Case Solver Status
-            analysis_type (enum): Analysis Type Enumeration
             analysis_settings_no (int): Analysis Settings Number
-            action_category (enum): Action Category enum
+            action_category (enum): Action Category Enumeration
             self_weight (list): Self-weight Considerations
                 for self-weight considerations;
                     self_weight = [True, self_weight_factor_x, self_weight_factor_y, self_weight_factor_z]
@@ -97,6 +97,7 @@ class LoadCase():
                     self_weight = [False]
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         '''
 
         # Client model | Load Case
