@@ -1,7 +1,8 @@
-from RFEM.initModel import Model, clearAtributes
-from RFEM.enums import DirectionalComponentCombinationRule, PeriodicResponseCombinationRule, CqsDampingRule
+from RFEM.initModel import Model, clearAtributes, GetAddonStatus, SetAddonStatus
+from RFEM.enums import DirectionalComponentCombinationRule, PeriodicResponseCombinationRule, CqsDampingRule, AddOn
 
 class SpectralAnalysisSettings():
+
     def __init__(self,
                  no: int = 1,
                  name: str = 'SRSS | SRSS',
@@ -31,7 +32,11 @@ class SpectralAnalysisSettings():
             constant_d_for_each_mode (float): Constant d for Each Mode
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         '''
+        # Check if Spectral Add-on is active.
+        if not GetAddonStatus(Model.clientModel, AddOn.spectral_active):
+            SetAddonStatus(Model.clientModel, AddOn.spectral_active)
 
         # Client model | Surface
         clientObject = model.clientModel.factory.create('ns0:spectral_analysis_settings')
@@ -58,12 +63,14 @@ class SpectralAnalysisSettings():
         # Save Results of All Selected Modes
         clientObject.save_results_of_all_selected_modes = save_mode_results
 
+        # CURRENTLY DEACTIVATED IN RFEM
         # Signed Results Using Dominant Mode
         clientObject.signed_results_using_dominant_mode = signed_dominant_mode_results
-
+        '''
         if signed_dominant_mode_results:
             if directional_combination != DirectionalComponentCombinationRule.SCALED_SUM:
                 raise Exception("WARNING: Signed results using dominant mode is only available with Scaled Sum Directional Combination.")
+        '''
 
         # Further Options
         if directional_combination == DirectionalComponentCombinationRule.SCALED_SUM:
