@@ -10,9 +10,17 @@ class ImposedNodalDeformation():
                  comment: str = '',
                  params: dict = None,
                  model = Model):
+
         '''
-        load_parameter:
-            load_parameter = [imposed_displacement_x, imposed_displacement_y, imposed_displacement_z, imposed_rotation_x, imposed_rotation_y imposed_rotation_z]
+        Args:
+            no (int): Load Tag
+            load_case_no (int): Assigned Load Case
+            node_no (str): Assigned node(s)
+            load_parameter (list): Load Parameters List
+                load_parameter = [imposed_displacement_x, imposed_displacement_y, imposed_displacement_z, imposed_rotation_x, imposed_rotation_y imposed_rotation_z]
+            comment (str, optional): Comments
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         '''
         # Client model | Imposed Nodal Deformation
         clientObject = model.clientModel.factory.create('ns0:imposed_nodal_deformation')
