@@ -8,7 +8,7 @@ class LineLoad():
                  load_case_no: int = 1,
                  lines_no: str = '1',
                  load_direction = LoadDirectionType.LOAD_DIRECTION_LOCAL_Z,
-                 magnitude: float = 0,
+                 magnitude: float = 0.0,
                  comment: str = '',
                  params: dict = None,
                  model = Model):
@@ -22,6 +22,7 @@ class LineLoad():
             magnitude (float): Magnitude of Line Load
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         '''
 
         # Client model | Line Load
@@ -82,9 +83,9 @@ class LineLoad():
             no (int): Load Tag
             load_case_no (int): Assigned Load Case
             lines_no (str): Assigned Line(s)
-            load_distribution (enum): Load Distribution Enumeration
-            load_direction (enum): Load Direction Enumeration
-            load_parameter: Load Parameter
+            load_distribution (enum): Line Load Distribution Enumeration
+            load_direction (enum): Line Load Direction Enumeration
+            load_parameter (flaot/list/list of lists): Load Parameter
                 for load_distribution == LOAD_DISTRIBUTION_UNIFORM:
                     load_parameter = magnitude
                 for load_distribution == LOAD_DISTRIBUTION_UNIFORM_TOTAL:
@@ -98,18 +99,19 @@ class LineLoad():
                 for load_distribution == LOAD_DISTRIBUTION_CONCENTRATED_2:
                     load_parameter = [relative_distance_a = False, relative_distance_b = False, magnitude_1, magnitude_2, distance_a, distance_b]
                 for load_distribution == LOAD_DISTRIBUTION_CONCENTRATED_VARYING:
-                    load_parameter = [[distance, delta_distance, magnitude], ...]
+                    load_parameter = [[distance, magnitude], ...]
                 for load_distribution == LOAD_DISTRIBUTION_TRAPEZOIDAL:
-                    load_parameter = [relative_distance_a = False, relative_distance_b = False,magnitude_1, magnitude_2, distance_a, distance_b]
+                    load_parameter = [relative_distance_a = False, relative_distance_b = False, magnitude_1, magnitude_2, distance_a, distance_b]
                 for load_distribution == LOAD_DISTRIBUTION_TAPERED:
-                    load_parameter = [relative_distance_a = False, relative_distance_b = False,magnitude_1, magnitude_2, distance_a, distance_b]
+                    load_parameter = [relative_distance_a = False, relative_distance_b = False, magnitude_1, magnitude_2, distance_a, distance_b]
                 for load_distribution == LOAD_DISTRIBUTION_PARABOLIC:
                     load_parameter = [magnitude_1, magnitude_2, magnitude_3]
                 for load_distribution == LOAD_DISTRIBUTION_VARYING:
-                    load_parameter = [[distance, delta_distance, magnitude], ...]
+                    load_parameter = [[distance, magnitude], ...]
             list_reference (bool): List Reference Bool
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         '''
 
         # Client model | Line Load
@@ -225,13 +227,12 @@ class LineLoad():
             clientObject.varying_load_parameters = model.clientModel.factory.create('ns0:line_load.varying_load_parameters')
 
             for i,j in enumerate(load_parameter):
-                if len(load_parameter[i]) != 3:
-                    raise Exception('WARNING: The load parameter sub-lists need to be of length 3. Kindly check sub-list inputs for completeness and correctness.')
+                if len(load_parameter[i]) != 2:
+                    raise Exception('WARNING: The load parameter sub-lists need to be of length 2. Kindly check sub-list inputs for completeness and correctness.')
                 mlvlp = model.clientModel.factory.create('ns0:line_load_varying_load_parameters_row')
                 mlvlp.no = i+1
                 mlvlp.row.distance = load_parameter[i][0]
-                mlvlp.row.delta_distance = load_parameter[i][1]
-                mlvlp.row.magnitude = load_parameter[i][2]
+                mlvlp.row.magnitude = load_parameter[i][1]
                 mlvlp.row.note = None
 
                 clientObject.varying_load_parameters.line_load_varying_load_parameters.append(mlvlp)
@@ -285,19 +286,18 @@ class LineLoad():
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_VARYING":
             try:
-                len(load_parameter[0])==3
+                len(load_parameter[0])==2
             except:
                 print("WARNING: LineLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
 
             clientObject.varying_load_parameters = model.clientModel.factory.create('ns0:line_load.varying_load_parameters')
             for i,j in enumerate(load_parameter):
-                if len(load_parameter[i]) != 3:
-                    raise Exception('WARNING: The load parameter sub-lists need to be of length 3. Kindly check sub-list inputs for completeness and correctness.')
+                if len(load_parameter[i]) != 2:
+                    raise Exception('WARNING: The load parameter sub-lists need to be of length 2. Kindly check sub-list inputs for completeness and correctness.')
                 mlvlp = model.clientModel.factory.create('ns0:line_load_varying_load_parameters_row')
                 mlvlp.no = i+1
                 mlvlp.row.distance = load_parameter[i][0]
-                mlvlp.row.delta_distance = load_parameter[i][1]
-                mlvlp.row.magnitude = load_parameter[i][2]
+                mlvlp.row.magnitude = load_parameter[i][1]
                 mlvlp.row.note = None
 
                 clientObject.varying_load_parameters.line_load_varying_load_parameters.append(mlvlp)
@@ -337,32 +337,33 @@ class LineLoad():
             no (int): Load Tag
             load_case_no (int): Assigned Load Case
             lines_no (str): Assigned Line(s)
-            load_distribution (enum): Load Distribution Enumeration
-            load_direction (enum): Load Direction Enumeration
-            load_parameter: Load Parameter
-                load_parameter == LOAD_DISTRIBUTION_UNIFORM:
+            load_distribution (enum): Line Load Distribution Enumeration
+            load_direction (enum): Line Load Direction Enumeration
+            load_parameter (float/list/list of lists): Load Parameter
+                for load_parameter == LOAD_DISTRIBUTION_UNIFORM:
                     load_parameter = magnitude
-                load_parameter == LOAD_DISTRIBUTION_CONCENTRATED_1:
+                for load_parameter == LOAD_DISTRIBUTION_CONCENTRATED_1:
                     load_parameter = [relative_distance = False, magnitude, distance_a]
-                load_parameter == LOAD_DISTRIBUTION_CONCENTRATED_N:
+                for load_parameter == LOAD_DISTRIBUTION_CONCENTRATED_N:
                     load_parameter = [relative_distance_a = False, relative_distance_b = False, magnitude, count_n, distance_a, distance_b]
-                load_parameter == LOAD_DISTRIBUTION_CONCENTRATED_2x2:
+                for load_parameter == LOAD_DISTRIBUTION_CONCENTRATED_2x2:
                     load_parameter = [relative_distance_a = False, relative_distance_b = False, relative_distance_c = False, magnitude, distance_a, distance_b, distance_c]
-                load_parameter == LOAD_DISTRIBUTION_CONCENTRATED_2:
+                for load_parameter == LOAD_DISTRIBUTION_CONCENTRATED_2:
                     load_parameter = [relative_distance_a = False, relative_distance_b = False, magnitude_1, magnitude_2, distance_a, distance_b]
-                load_parameter == LOAD_DISTRIBUTION_CONCENTRATED_VARYING:
-                    load_parameter = [[distance, delta_distance, magnitude], ...]
-                load_parameter == LOAD_DISTRIBUTION_TRAPEZOIDAL:
+                for load_parameter == LOAD_DISTRIBUTION_CONCENTRATED_VARYING:
+                    load_parameter = [[distance, magnitude], ...]
+                for load_parameter == LOAD_DISTRIBUTION_TRAPEZOIDAL:
                     load_parameter = [relative_distance_a = False, relative_distance_b = False,magnitude_1, magnitude_2, distance_a, distance_b]
-                load_parameter == LOAD_DISTRIBUTION_TAPERED:
+                for load_parameter == LOAD_DISTRIBUTION_TAPERED:
                     load_parameter = [relative_distance_a = False, relative_distance_b = False,magnitude_1, magnitude_2, distance_a, distance_b]
-                load_parameter == LOAD_DISTRIBUTION_PARABOLIC:
+                for load_parameter == LOAD_DISTRIBUTION_PARABOLIC:
                     load_parameter = [magnitude_1, magnitude_2, magnitude_3]
-                load_parameter == LOAD_DISTRIBUTION_VARYING:
-                    load_parameter = [[distance, delta_distance, magnitude], ...]
+                for load_parameter == LOAD_DISTRIBUTION_VARYING:
+                    load_parameter = [[distance, magnitude], ...]
             list_reference (bool): List Reference Bool
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         '''
 
         # Client model | Line Load
@@ -471,20 +472,19 @@ class LineLoad():
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_CONCENTRATED_VARYING":
             try:
-                len(load_parameter[0])==3
+                len(load_parameter[0])==2
             except:
                 print("WARNING: LineLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
 
             clientObject.varying_load_parameters = model.clientModel.factory.create('ns0:line_load.varying_load_parameters')
 
             for i,j in enumerate(load_parameter):
-                if len(load_parameter[i]) != 3:
-                    raise Exception('WARNING: The load parameter sub-lists need to be of length 3. Kindly check sub-list inputs for completeness and correctness.')
+                if len(load_parameter[i]) != 2:
+                    raise Exception('WARNING: The load parameter sub-lists need to be of length 2. Kindly check sub-list inputs for completeness and correctness.')
                 mlvlp = model.clientModel.factory.create('ns0:line_load_varying_load_parameters_row')
                 mlvlp.no = i+1
                 mlvlp.row.distance = load_parameter[i][0]
-                mlvlp.row.delta_distance = load_parameter[i][1]
-                mlvlp.row.magnitude = load_parameter[i][2]
+                mlvlp.row.magnitude = load_parameter[i][1]
                 mlvlp.row.note = None
 
                 clientObject.varying_load_parameters.line_load_varying_load_parameters.append(mlvlp)
@@ -538,19 +538,18 @@ class LineLoad():
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_VARYING":
             try:
-                len(load_parameter[0])==3
+                len(load_parameter[0])==2
             except:
                 print("WARNING: LineLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
 
             clientObject.varying_load_parameters = model.clientModel.factory.create('ns0:line_load.varying_load_parameters')
             for i,j in enumerate(load_parameter):
-                if len(load_parameter[i]) != 3:
-                    raise Exception('WARNING: The load parameter sub-lists need to be of length 3. Kindly check sub-list inputs for completeness and correctness.')
+                if len(load_parameter[i]) != 2:
+                    raise Exception('WARNING: The load parameter sub-lists need to be of length 2. Kindly check sub-list inputs for completeness and correctness.')
                 mlvlp = model.clientModel.factory.create('ns0:line_load_varying_load_parameters_row')
                 mlvlp.no = i+1
                 mlvlp.row.distance = load_parameter[i][0]
-                mlvlp.row.delta_distance = load_parameter[i][1]
-                mlvlp.row.magnitude = load_parameter[i][2]
+                mlvlp.row.magnitude = load_parameter[i][1]
                 mlvlp.row.note = None
 
                 clientObject.varying_load_parameters.line_load_varying_load_parameters.append(mlvlp)
@@ -595,6 +594,7 @@ class LineLoad():
                     mass_components = [mass_x, mass_y, mass_z]
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         '''
 
         # Client model | Line Load
