@@ -4,6 +4,7 @@ from RFEM.enums import MemberLoadEccentricityHorizontalAlignment, MemberLoadEcce
 from RFEM.enums import MemberLoadAxisDefinitionType, MemberLoadAxisDefinitionAxisOrientation, MemberLoadAxisDefinition
 
 class MemberLoad():
+
     def __init__(self,
                  no: int = 1,
                  load_case_no: int = 1,
@@ -81,13 +82,13 @@ class MemberLoad():
             no (int): Load Tag
             load_case_no (int): Assigned Load Case
             members_no (str): Assigned Member(s)
-            load_distribution (enum): Load Distribution Enumeration
-            load_direction (enum): Load Direction Enumeration
-            load_parameter (list): Load Parameter List
+            load_distribution (enum): Member Load Distribution Enumeration
+            load_direction (enum): Member Load Direction Enumeration
+            load_parameter (float/list/list of lists): Load Parameter List
                 for load_distribution == LOAD_DISTRIBUTION_UNIFORM:
-                    load_parameter = [magnitude]
+                    load_parameter = magnitude
                 for load_distribution == LOAD_DISTRIBUTION_UNIFORM_TOTAL:
-                    load_parameter = [magnitude]
+                    load_parameter = magnitude
                 for load_distribution == LOAD_DISTRIBUTION_CONCENTRATED_1:
                     load_parameter = [relative_distance = False, magnitude, distance_a]
                 for load_distribution == LOAD_DISTRIBUTION_CONCENTRATED_N:
@@ -97,7 +98,7 @@ class MemberLoad():
                 for load_distribution == LOAD_DISTRIBUTION_CONCENTRATED_2:
                     load_parameter = [relative_distance_a = False, relative_distance_b = False, magnitude_1, magnitude_2, distance_a, distance_b]
                 for load_distribution == LOAD_DISTRIBUTION_CONCENTRATED_VARYING:
-                    load_parameter = [[distance, delta_distance, magnitude], ...]
+                    load_parameter = [[distance, magnitude], ...]
                 for load_distribution == LOAD_DISTRIBUTION_TRAPEZOIDAL:
                     load_parameter = [relative_distance_a = False, relative_distance_b = False,magnitude_1, magnitude_2, distance_a, distance_b]
                 for load_distribution == LOAD_DISTRIBUTION_TAPERED:
@@ -105,22 +106,23 @@ class MemberLoad():
                 for load_distribution == LOAD_DISTRIBUTION_PARABOLIC:
                     load_parameter = [magnitude_1, magnitude_2, magnitude_3]
                 for load_distribution == LOAD_DISTRIBUTION_VARYING:
-                    load_parameter = [[distance, delta_distance, magnitude], ...]
+                    load_parameter = [[distance, magnitude], ...]
                 for load_distribution == LOAD_DISTRIBUTION_VARYING_IN_Z:
-                    load_parameter = [[distance, delta_distance, magnitude], ...]
+                    load_parameter = [[distance, magnitude], ...]
             force_eccentricity (bool): Enable/Disable Force Eccentricity Option
             list_reference (bool): Enable/Disable List Reference Option
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
                 for force_eccentricity == True:
-                {'eccentricity_horizontal_alignment': MemberLoadEccentricityHorizontalAlignment.ALIGN_NONE,
-                'eccentricity_vertical_alignment': MemberLoadEccentricityVerticalAlignment.ALIGN_NONE,
-                'eccentricity_section_middle': MemberLoadEccentricitySectionMiddle.LOAD_ECCENTRICITY_SECTION_MIDDLE_CENTER_OF_GRAVITY,
-                'is_eccentricity_at_end_different_from_start': False,
-                'eccentricity_y_at_end': 0.0,
-                'eccentricity_y_at_start': 0.0,
-                'eccentricity_z_at_end': 0.0,
-                'eccentricity_z_at_start': 0.0}
+                    params = {'eccentricity_horizontal_alignment': MemberLoadEccentricityHorizontalAlignment.ALIGN_NONE,
+                        'eccentricity_vertical_alignment': MemberLoadEccentricityVerticalAlignment.ALIGN_NONE,
+                        'eccentricity_section_middle': MemberLoadEccentricitySectionMiddle.LOAD_ECCENTRICITY_SECTION_MIDDLE_CENTER_OF_GRAVITY,
+                        'is_eccentricity_at_end_different_from_start': False,
+                        'eccentricity_y_at_end': 0.0,
+                        'eccentricity_y_at_start': 0.0,
+                        'eccentricity_z_at_end': 0.0,
+                        'eccentricity_z_at_start': 0.0}
+            model (RFEM Class, optional): Model to be edited
         """
         # Client model | Member Load
         clientObject = model.clientModel.factory.create('ns0:member_load')
@@ -212,7 +214,7 @@ class MemberLoad():
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_CONCENTRATED_VARYING":
             try:
-                len(load_parameter[0])==3
+                len(load_parameter[0])==2
             except:
                 print("WARNING: MemberLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
 
@@ -222,8 +224,7 @@ class MemberLoad():
                 mlvlp = model.clientModel.factory.create('ns0:member_load_varying_load_parameters_row')
                 mlvlp.no = i+1
                 mlvlp.row.distance = load_parameter[i][0]
-                mlvlp.row.delta_distance = load_parameter[i][1]
-                mlvlp.row.magnitude = load_parameter[i][2]
+                mlvlp.row.magnitude = load_parameter[i][1]
                 mlvlp.row.note = None
                 mlvlp.row.magnitude_t_c = 0.0
                 mlvlp.row.magnitude_delta_t = 0.0
@@ -271,7 +272,7 @@ class MemberLoad():
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_VARYING":
             try:
-                len(load_parameter[0])==3
+                len(load_parameter[0])==2
             except:
                 print("WARNING: MemberLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
 
@@ -280,8 +281,7 @@ class MemberLoad():
                 mlvlp = model.clientModel.factory.create('ns0:member_load_varying_load_parameters_row')
                 mlvlp.no = i+1
                 mlvlp.row.distance = load_parameter[i][0]
-                mlvlp.row.delta_distance = load_parameter[i][1]
-                mlvlp.row.magnitude = load_parameter[i][2]
+                mlvlp.row.magnitude = load_parameter[i][1]
                 mlvlp.row.note = None
                 mlvlp.row.magnitude_t_c = 0.0
                 mlvlp.row.magnitude_delta_t = 0.0
@@ -292,7 +292,7 @@ class MemberLoad():
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_VARYING_IN_Z":
             try:
-                len(load_parameter[0])==3
+                len(load_parameter[0])==2
             except:
                 print("WARNING: MemberLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
 
@@ -301,8 +301,7 @@ class MemberLoad():
                 mlvlp = model.clientModel.factory.create('ns0:member_load_varying_load_parameters_row')
                 mlvlp.no = i+1
                 mlvlp.row.distance = load_parameter[i][0]
-                mlvlp.row.delta_distance = load_parameter[i][1]
-                mlvlp.row.magnitude = load_parameter[i][2]
+                mlvlp.row.magnitude = load_parameter[i][1]
                 mlvlp.row.note = None
                 mlvlp.row.magnitude_t_c = 0.0
                 mlvlp.row.magnitude_delta_t = 0.0
@@ -385,7 +384,7 @@ class MemberLoad():
             members_no (str): Assigned Member(s)
             load_distribution (enum): Load Distribution Enumeration
             load_direction (enum): Load Direction Enumeration
-            load_parameter (list): Load Parameter List
+            load_parameter (float/list/list of lists): Load Parameter List
                 for load_distribution == LOAD_DISTRIBUTION_UNIFORM:
                     load_parameter = magnitude
                 for load_distribution == LOAD_DISTRIBUTION_CONCENTRATED_1:
@@ -397,7 +396,7 @@ class MemberLoad():
                 for load_distribution == LOAD_DISTRIBUTION_CONCENTRATED_2:
                     load_parameter = [relative_distance_a = False, relative_distance_b = False, magnitude_1, magnitude_2, distance_a, distance_b]
                 for load_distribution == LOAD_DISTRIBUTION_CONCENTRATED_VARYING:
-                    load_parameter = [[distance, delta_distance, magnitude], ...]
+                    load_parameter = [[distance, magnitude], ...]
                 for load_distribution == LOAD_DISTRIBUTION_TRAPEZOIDAL:
                     load_parameter = [relative_distance_a = False, relative_distance_b = False,magnitude_1, magnitude_2, distance_a, distance_b]
                 for load_distribution == LOAD_DISTRIBUTION_TAPERED:
@@ -405,10 +404,11 @@ class MemberLoad():
                 for load_distribution == LOAD_DISTRIBUTION_PARABOLIC:
                     load_parameter = [magnitude_1, magnitude_2, magnitude_3]
                 for load_distribution == LOAD_DISTRIBUTION_VARYING:
-                    load_parameter = [[distance, delta_distance, magnitude], ...]
+                    load_parameter = [[distance, magnitude], ...]
             list_reference (bool): Enable/Disable List Reference Option
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         """
         # Client model | Member Load
         clientObject = model.clientModel.factory.create('ns0:member_load')
@@ -500,7 +500,7 @@ class MemberLoad():
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_CONCENTRATED_VARYING":
             try:
-                len(load_parameter[0])==3
+                len(load_parameter[0])==2
             except:
                 print("WARNING: MemberLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
 
@@ -510,8 +510,7 @@ class MemberLoad():
                 mlvlp = model.clientModel.factory.create('ns0:member_load_varying_load_parameters_row')
                 mlvlp.no = i+1
                 mlvlp.row.distance = load_parameter[i][0]
-                mlvlp.row.delta_distance = load_parameter[i][1]
-                mlvlp.row.magnitude = load_parameter[i][2]
+                mlvlp.row.magnitude = load_parameter[i][1]
                 mlvlp.row.note = None
                 mlvlp.row.magnitude_t_c = 0.0
                 mlvlp.row.magnitude_delta_t = 0.0
@@ -559,7 +558,7 @@ class MemberLoad():
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_VARYING":
             try:
-                len(load_parameter[0])==3
+                len(load_parameter[0])==2
             except:
                 print("WARNING: MemberLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
 
@@ -568,8 +567,7 @@ class MemberLoad():
                 mlvlp = model.clientModel.factory.create('ns0:member_load_varying_load_parameters_row')
                 mlvlp.no = i+1
                 mlvlp.row.distance = load_parameter[i][0]
-                mlvlp.row.delta_distance = load_parameter[i][1]
-                mlvlp.row.magnitude = load_parameter[i][2]
+                mlvlp.row.magnitude = load_parameter[i][1]
                 mlvlp.row.note = None
                 mlvlp.row.magnitude_t_c = 0.0
                 mlvlp.row.magnitude_delta_t = 0.0
@@ -618,6 +616,7 @@ class MemberLoad():
                     mass_components = [Mx, My, Mz, Ix, Iy, Iz]
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         """
         # Client model | Member Load
         clientObject = model.clientModel.factory.create('ns0:member_load')
@@ -681,9 +680,9 @@ class MemberLoad():
             no (int): Load Tag
             load_case_no (int): Assigned Load Case
             members_no (str): Assigned Member(s)
-            load_distribution (enum): Load Distribution Enumeration
-            load_direction (enum): Load Direction Enumeration
-            load_parameter (list): Load Parameter List
+            load_distribution (enum): Member Load Distribution Enumeration
+            load_direction (enum): Member Load Direction Enumeration
+            load_parameter (list/list of lists): Load Parameter List
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_UNIFORM:
                     load_parameter = [tt, tb]
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_TRAPEZIODAL:
@@ -696,11 +695,12 @@ class MemberLoad():
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_PARABOLIC:
                     load_parameter = [tb1, tb2, tb3, tt1, tt2, tt3]
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_VARYING:
-                    load_parameter = [[distance, delta_distance, magnitude], ...]
+                    load_parameter = [[distance, magnitude], ...]
             list_reference (bool): List Reference Boolean
             load_over_total_length (bool): Enable/Disable Load Over Total Length Option
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         '''
 
         # Client model | Member Load
@@ -789,7 +789,7 @@ class MemberLoad():
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_VARYING":
             try:
-                len(load_parameter[0])==4
+                len(load_parameter[0])==3
             except:
                 print("WARNING: MemberLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
 
@@ -798,13 +798,12 @@ class MemberLoad():
                 mlvlp = model.clientModel.factory.create('ns0:member_load_varying_load_parameters_row')
                 mlvlp.no = i+1
                 mlvlp.row.distance = load_parameter[i][0]
-                mlvlp.row.delta_distance = load_parameter[i][1]
-                mlvlp.row.magnitude = load_parameter[i][2]
+                mlvlp.row.magnitude = load_parameter[i][1]
                 mlvlp.row.note = None
-                mlvlp.row.magnitude_t_c = load_parameter[i][2]
-                mlvlp.row.magnitude_delta_t = load_parameter[i][3]
-                mlvlp.row.magnitude_t_t = load_parameter[i][2]
-                mlvlp.row.magnitude_t_b = load_parameter[i][3]
+                mlvlp.row.magnitude_t_c = load_parameter[i][1]
+                mlvlp.row.magnitude_delta_t = load_parameter[i][2]
+                mlvlp.row.magnitude_t_t = load_parameter[i][1]
+                mlvlp.row.magnitude_t_b = load_parameter[i][2]
 
                 clientObject.varying_load_parameters.member_load_varying_load_parameters.append(mlvlp)
 
@@ -841,9 +840,9 @@ class MemberLoad():
             no (int): Load Tag
             load_case_no (int): Assigned Load Case
             members_no (str): Assigned Member(s)
-            load_distribution (enum): Load Distribution
-            load_direction (enum): Load Direction Enumeration
-            load_parameter (list): Load Parameter List
+            load_distribution (enum): Member Load Distribution
+            load_direction (enum): Member Load Direction Enumeration
+            load_parameter (list/list of lists): Load Parameter List
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_UNIFORM:
                     load_parameter = [tc, delta_t]
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_TRAPEZIODAL:
@@ -856,11 +855,12 @@ class MemberLoad():
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_PARABOLIC:
                     load_parameter = [delta_t_1, delta_t_2, delta_t_3, t_c_1, t_c_2, t_c_3]
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_VARYING:
-                    load_parameter = [[distance, delta_distance, magnitude], ...]
+                    load_parameter = [[distance, magnitude], ...]
             list_reference (bool): Enable/Disable List Reference Option
             load_over_total_length (bool): Enable/Disable Load Over Total Length Option
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         '''
 
         # Client model | Member Load
@@ -949,7 +949,7 @@ class MemberLoad():
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_VARYING":
             try:
-                len(load_parameter[0])==4
+                len(load_parameter[0])==3
             except:
                 print("WARNING: MemberLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
 
@@ -958,13 +958,12 @@ class MemberLoad():
                 mlvlp = model.clientModel.factory.create('ns0:member_load_varying_load_parameters_row')
                 mlvlp.no = i+1
                 mlvlp.row.distance = load_parameter[i][0]
-                mlvlp.row.delta_distance = load_parameter[i][1]
-                mlvlp.row.magnitude = load_parameter[i][2]
+                mlvlp.row.magnitude = load_parameter[i][1]
                 mlvlp.row.note = None
-                mlvlp.row.magnitude_t_c = load_parameter[i][2]
-                mlvlp.row.magnitude_delta_t = load_parameter[i][3]
-                mlvlp.row.magnitude_t_t = load_parameter[i][2]
-                mlvlp.row.magnitude_t_b = load_parameter[i][3]
+                mlvlp.row.magnitude_t_c = load_parameter[i][1]
+                mlvlp.row.magnitude_delta_t = load_parameter[i][2]
+                mlvlp.row.magnitude_t_t = load_parameter[i][1]
+                mlvlp.row.magnitude_t_b = load_parameter[i][2]
 
                 clientObject.varying_load_parameters.member_load_varying_load_parameters.append(mlvlp)
 
@@ -1001,9 +1000,9 @@ class MemberLoad():
             no (int): Load Tag
             load_case_no (int): Assigned Load Case
             members_no (str): Assigned Member(s)
-            load_distribution (enum): Load Distribution Enumeration
-            load_direction (enum): Load Direction Enumeration
-            load_parameter (list): Load Parameter List
+            load_distribution (enum): Member Load Distribution Enumeration
+            load_direction (enum): Member Load Direction Enumeration
+            load_parameter (list/list of lists): Load Parameter List
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_UNIFORM:
                     load_parameter = [epsilon]
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_TRAPEZIODAL:
@@ -1013,11 +1012,12 @@ class MemberLoad():
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_TAPERED:
                     load_parameter = [epsilon1, epsilon2, epsilon3]
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_VARYING:
-                    load_parameter = [[distance, delta_distance, magnitude], ...]
+                    load_parameter = [[distance, magnitude], ...]
             list_reference (bool): Enable/Disable List Reference Option
             load_over_total_length (bool): Enable/Disable Load Over Total Length Option
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         '''
 
         # Client model | Member Load
@@ -1098,7 +1098,7 @@ class MemberLoad():
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_VARYING":
             try:
-                len(load_parameter[0])==3
+                len(load_parameter[0])==2
             except:
                 print("WARNING: MemberLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
 
@@ -1107,8 +1107,7 @@ class MemberLoad():
                 mlvlp = model.clientModel.factory.create('ns0:member_load_varying_load_parameters_row')
                 mlvlp.no = i+1
                 mlvlp.row.distance = load_parameter[i][0]
-                mlvlp.row.delta_distance = load_parameter[i][1]
-                mlvlp.row.magnitude = load_parameter[i][2]
+                mlvlp.row.magnitude = load_parameter[i][1]
                 mlvlp.row.note = None
                 mlvlp.row.magnitude_t_c = 0.0
                 mlvlp.row.magnitude_delta_t = 0.0
@@ -1147,10 +1146,11 @@ class MemberLoad():
             no (int): Load Tag
             load_case_no (int): Assigned Load Case
             members_no (str): Assigned Member(s)
-            load_direction (enum): Load Direction Enumeration
+            load_direction (enum): Member Load Direction Enumeration
             magnitude (float): Load Magnitude
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         '''
 
         # Client model | Member Load
@@ -1211,9 +1211,9 @@ class MemberLoad():
             no (int): Load Tag
             load_case_no (int): Assigned Load Case
             members_no (str): Assigned Member(s)
-            load_distribution (enum):Load Distribution Enumeration
-            load_direction (enum): Load Direction Enumeration
-            load_parameter (list): Load Parameter List
+            load_distribution (enum): Member Load Distribution Enumeration
+            load_direction (enum): Member Load Direction Enumeration
+            load_parameter (list/list of lists): Load Parameter List
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_UNIFORM:
                     load_parameter = [magnitude]
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_TRAPEZIODAL:
@@ -1223,11 +1223,12 @@ class MemberLoad():
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_PARABOLIC:
                     load_parameter = [magnitude_1, magnitude_2, magnitude_3]
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_VARYING:
-                    load_parameter = [[distance, delta_distance, magnitude], ...]
+                    load_parameter = [[distance, magnitude], ...]
             list_reference (bool): Enable/Disable List Reference Option
             load_over_total_length (bool): Enable/Disable Load Over Total Length Option
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         '''
 
         # Client model | Member Load
@@ -1308,7 +1309,7 @@ class MemberLoad():
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_VARYING":
             try:
-                len(load_parameter[0])==3
+                len(load_parameter[0])==2
             except:
                 print("WARNING: MemberLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
 
@@ -1317,8 +1318,7 @@ class MemberLoad():
                 mlvlp = model.clientModel.factory.create('ns0:member_load_varying_load_parameters_row')
                 mlvlp.no = i+1
                 mlvlp.row.distance = load_parameter[i][0]
-                mlvlp.row.delta_distance = load_parameter[i][1]
-                mlvlp.row.magnitude = load_parameter[i][2]
+                mlvlp.row.magnitude = load_parameter[i][1]
                 mlvlp.row.note = None
                 mlvlp.row.magnitude_t_c = 0.0
                 mlvlp.row.magnitude_delta_t = 0.0
@@ -1357,10 +1357,11 @@ class MemberLoad():
             no (int): Load Tag
             load_case_no (int): Assigned Load Case
             members_no (str): Assigned Member(s)
-            load_direction (enum): Load Direction Enumeration
+            load_direction (enum): Member Load Direction Enumeration
             magnitude (float): Load Magnitude
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         '''
 
         # Client model | Member Load
@@ -1421,9 +1422,9 @@ class MemberLoad():
             no (int): Load Tag
             load_case_no (int): Assigned Load Case
             members_no (str): Assigned Member(s)
-            load_distribution (enum): Load Distribution Enumeration
-            load_direction (enum): Load Direction Enumeration
-            load_parameter (list): Load Parameter List
+            load_distribution (enum): Member Load Distribution Enumeration
+            load_direction (enum): Member Load Direction Enumeration
+            load_parameter (list/list of lists): Load Parameter List
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_UNIFORM:
                     load_parameter = [magnitude]
                 for load_distrubition == MemberLoadDistribution.LOAD_DISTRIBUTION_CONCENTRATED_1:
@@ -1435,7 +1436,7 @@ class MemberLoad():
                 for load_distrubition == MemberLoadDistribution.LOAD_DISTRIBUTION_CONCENTRATED_2:
                     load_parameter = [magnitude_1, magnitude_2, distance_a_is_defined_as_relative = False, distance_b_is_defined_as_relative = False, distance_a, distance_b]
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_CONCENTRATED_VARYING:
-                    load_parameter = [[distance, delta_distance, magnitude], ...]
+                    load_parameter = [[distance, magnitude], ...]
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_TRAPEZIODAL:
                     load_parameter = [magnitude_1, magnitude_2, distance_a_relative = False, distance_a_relative = False, a_distance, b_distance]
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_TAPERED:
@@ -1443,11 +1444,12 @@ class MemberLoad():
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_PARABOLIC:
                     load_parameter = [magnitude_1, magnitude_2, magnitude_3]
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_VARYING:
-                    load_parameter = [[distance, delta_distance, magnitude], ...]
+                    load_parameter = [[distance, magnitude], ...]
             list_reference (bool): Enable/Disable List Reference Option
             load_over_total_length (bool): Enable/Disable Load Over Total Length Option
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         '''
 
         # Client model | Member Load
@@ -1542,7 +1544,7 @@ class MemberLoad():
 
         elif load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_CONCENTRATED_VARYING:
             try:
-                len(load_parameter[0])==3
+                len(load_parameter[0])==2
             except:
                 print("WARNING: MemberLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
 
@@ -1551,8 +1553,7 @@ class MemberLoad():
                 mlvlp = model.clientModel.factory.create('ns0:member_load_varying_load_parameters_row')
                 mlvlp.no = i+1
                 mlvlp.row.distance = load_parameter[i][0]
-                mlvlp.row.delta_distance = load_parameter[i][1]
-                mlvlp.row.magnitude = load_parameter[i][2]
+                mlvlp.row.magnitude = load_parameter[i][1]
                 mlvlp.row.note = None
                 mlvlp.row.magnitude_t_c = 0.0
                 mlvlp.row.magnitude_delta_t = 0.0
@@ -1607,7 +1608,7 @@ class MemberLoad():
 
         elif load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_VARYING:
             try:
-                len(load_parameter[0])==3
+                len(load_parameter[0])==2
             except:
                 print("WARNING: MemberLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
 
@@ -1616,8 +1617,7 @@ class MemberLoad():
                 mlvlp = model.clientModel.factory.create('ns0:member_load_varying_load_parameters_row')
                 mlvlp.no = i+1
                 mlvlp.row.distance = load_parameter[i][0]
-                mlvlp.row.delta_distance = load_parameter[i][1]
-                mlvlp.row.magnitude = load_parameter[i][2]
+                mlvlp.row.magnitude = load_parameter[i][1]
                 mlvlp.row.note = None
                 mlvlp.row.magnitude_t_c = 0.0
                 mlvlp.row.magnitude_delta_t = 0.0
@@ -1659,9 +1659,9 @@ class MemberLoad():
             no (int): Load Tag
             load_case_no (int): Assigned Load Case
             members_no (str): Assigned Member(s)
-            load_distribution (enum): Load Distribution Enumeration
-            load_direction (enum): Load Direction Enumeration
-            load_parameter (list): Load Parameter List
+            load_distribution (enum): Member Load Distribution Enumeration
+            load_direction (enum): Member Load Direction Enumeration
+            load_parameter (list/list of lists): Load Parameter List
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_UNIFORM:
                     load_parameter = [magnitude]
                 for load_distrubition == MemberLoadDistribution.LOAD_DISTRIBUTION_CONCENTRATED_1:
@@ -1673,7 +1673,7 @@ class MemberLoad():
                 for load_distrubition == MemberLoadDistribution.LOAD_DISTRIBUTION_CONCENTRATED_2:
                     load_parameter = [magnitude_1, magnitude_2, distance_a_is_defined_as_relative = False, distance_b_is_defined_as_relative = False, distance_a, distance_b]
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_CONCENTRATED_VARYING:
-                    load_parameter = [[distance, delta_distance, magnitude], ...]
+                    load_parameter = [[distance, magnitude], ...]
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_TRAPEZIODAL:
                     load_parameter = [magnitude_1, magnitude_2, distance_a_relative = False, distance_a_relative = False, a_distance, b_distance]
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_TAPERED:
@@ -1681,11 +1681,12 @@ class MemberLoad():
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_PARABOLIC:
                     load_parameter = [magnitude_1, magnitude_2, magnitude_3]
                 for load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_VARYING:
-                    load_parameter = [[distance, delta_distance, magnitude], ...]
+                    load_parameter = [[distance, magnitude], ...]
             list_reference (bool): Enable/Disable List Reference Option
             load_over_total_length (bool): Enable/Disable Load Over Total Length Option
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         '''
 
         # Client model | Member Load
@@ -1780,7 +1781,7 @@ class MemberLoad():
 
         elif load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_CONCENTRATED_VARYING:
             try:
-                len(load_parameter[0])==3
+                len(load_parameter[0])==2
             except:
                 print("WARNING: MemberLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
 
@@ -1789,8 +1790,7 @@ class MemberLoad():
                 mlvlp = model.clientModel.factory.create('ns0:member_load_varying_load_parameters_row')
                 mlvlp.no = i+1
                 mlvlp.row.distance = load_parameter[i][0]
-                mlvlp.row.delta_distance = load_parameter[i][1]
-                mlvlp.row.magnitude = load_parameter[i][2]
+                mlvlp.row.magnitude = load_parameter[i][1]
                 mlvlp.row.note = None
                 mlvlp.row.magnitude_t_c = 0.0
                 mlvlp.row.magnitude_delta_t = 0.0
@@ -1845,7 +1845,7 @@ class MemberLoad():
 
         elif load_distribution == MemberLoadDistribution.LOAD_DISTRIBUTION_VARYING:
             try:
-                len(load_parameter[0])==3
+                len(load_parameter[0])==2
             except:
                 print("WARNING: MemberLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
 
@@ -1854,8 +1854,7 @@ class MemberLoad():
                 mlvlp = model.clientModel.factory.create('ns0:member_load_varying_load_parameters_row')
                 mlvlp.no = i+1
                 mlvlp.row.distance = load_parameter[i][0]
-                mlvlp.row.delta_distance = load_parameter[i][1]
-                mlvlp.row.magnitude = load_parameter[i][2]
+                mlvlp.row.magnitude = load_parameter[i][1]
                 mlvlp.row.note = None
                 mlvlp.row.magnitude_t_c = 0.0
                 mlvlp.row.magnitude_delta_t = 0.0
@@ -1894,10 +1893,11 @@ class MemberLoad():
             no (int): Load Tag
             load_case_no (int): Assigned Load Case
             members_no (str): Assigned Member(s)
-            load_direction_orientation (enum): Load Direction Enumeration
+            load_direction_orientation (enum): Member Load Direction Enumeration
             specific_weight (float): Specific Weight
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         '''
 
         # Client model | Member Load
@@ -1959,11 +1959,12 @@ class MemberLoad():
             no (int): Load Tag
             load_case_no (int): Assigned Load Case
             members_no (str): Assigned Member(s)
-            load_direction_orientation (enum): Load Direction Enumeration
+            load_direction_orientation (enum): Member Load Direction Enumeration
             specific_weight (float): Specific Weight
             filling_height (float): Filling Height
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         '''
 
         # Client model | Member Load
@@ -2029,6 +2030,7 @@ class MemberLoad():
             pressure (float): Pressure
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         '''
 
         # Client model | Member Load
@@ -2080,8 +2082,8 @@ class MemberLoad():
                  axis_definition_type = MemberLoadAxisDefinitionType.AXIS_DEFINITION_TWO_POINTS,
                  axis_orientation = MemberLoadAxisDefinitionAxisOrientation.AXIS_POSITIVE,
                  axis_definition = MemberLoadAxisDefinition.AXIS_X,
-                 axis_definition_p1 = [1,0,1],
-                 axis_definition_p2 = [0,1,0],
+                 axis_definition_p1: list = [1,0,1],
+                 axis_definition_p2: list = [0,1,0],
                  comment: str = '',
                  params: dict = None,
                  model = Model):
@@ -2093,13 +2095,14 @@ class MemberLoad():
             members_no (str): Assigned Member(s)
             angular_acceleration (float): Angular Acceleration
             angular_velocity (float): Angular Velocity
-            axis_definition_type (enum): Axis Definition Type Enumeration
-            axis_orientation (enum): Axis Orientation Enumeration
-            axis_definition (enum): Axis Definition Enumeration
+            axis_definition_type (enum): Member Load Axis Definition Type Enumeration
+            axis_orientation (enum): Member Load Axis Orientation Enumeration
+            axis_definition (enum): Member Load Axis Definition Enumeration
             axis_definition_p1 (list): P1 List [X, Y, Z]
             axis_definition_p2 (list): P2 List [X, Y, Z]
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         '''
 
         # Client model | Member Load
