@@ -10,10 +10,23 @@ class SolidLoad():
                  load_type = SolidLoadType.LOAD_TYPE_FORCE,
                  load_distribution = SolidLoadDistribution.LOAD_DISTRIBUTION_UNIFORM,
                  load_direction = SolidLoadDirection.LOAD_DIRECTION_GLOBAL_Z_OR_USER_DEFINED_W_TRUE,
-                 magnitude: float = 0,
+                 magnitude: float = 0.0,
                  comment: str = '',
                  params: dict = None,
                  model = Model):
+        """
+        Args:
+            no (int): Load Tag
+            load_case_no (int): Assigned Load Case
+            solids_no (str): Assigned Solids
+            load_type (enum): Solid Load Type Enumeration
+            load_distribution (enum): Solid Load Distribution Enumeration
+            load_direction (enum): Solid Load Direction Enumeration
+            magnitude (float): Uniform Magnitude
+            comment (str, optional): Comments
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
+        """
 
         # Client model | Solid Load
         clientObject = model.clientModel.factory.create('ns0:solid_load')
@@ -59,10 +72,21 @@ class SolidLoad():
               load_case_no: int = 1,
               solids_no: str= '1',
               load_direction = SolidLoadDirection.LOAD_DIRECTION_GLOBAL_Z_OR_USER_DEFINED_W_TRUE,
-              magnitude: float = 0,
+              magnitude: float = 0.0,
               comment: str = '',
               params: dict = None,
               model = Model):
+        """
+        Args:
+            no (int): Load Tag
+            load_case_no (int): Assigned Load Case
+            solids_no (str): Assigned Solids
+            load_direction (enum): Solid Load Direction Enumeration
+            magnitude (float): Uniform Magnitude
+            comment (str, optional): Comments
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
+        """
 
         # Client model | Solid Load
         clientObject = model.clientModel.factory.create('ns0:solid_load')
@@ -113,13 +137,23 @@ class SolidLoad():
                     params: dict = None,
                     model = Model):
         '''
-        load_parameter:
-            LOAD_DISTRIBUTION_UNIFORM: load_parameter = magnitude
-            LOAD_DISTRIBUTION_LINEAR_IN_X: load_parameter = [magnitude_1, magnitude_2, node_1, node_2]
-            LOAD_DISTRIBUTION_LINEAR_IN_Y: load_parameter = [magnitude_1, magnitude_2, node_1, node_2]
-            LOAD_DISTRIBUTION_LINEAR_IN_Z: load_parameter = [magnitude_1, magnitude_2, node_1, node_2]
-        params:
-            {''}
+        Args:
+            no (int): Load Tag
+            load_case_no (int): Assigned Load Case
+            solids_no (str): Assigned Solids
+            load_distribution (enum): Solid Load Distribution Enumeration
+            load_parameter (float/list): Load Parameter List
+                for load_distribution == SolidLoadDistribution.LOAD_DISTRIBUTION_UNIFORM:
+                    load_parameter = magnitude
+                for load_distribution == SolidLoadDistribution.LOAD_DISTRIBUTION_LINEAR_IN_X:
+                    load_parameter = [magnitude_1, magnitude_2, node_1, node_2]
+                for load_distribution == SolidLoadDistribution.LOAD_DISTRIBUTION_LINEAR_IN_Y:
+                    load_parameter = [magnitude_1, magnitude_2, node_1, node_2]
+                for load_distribution == SolidLoadDistribution.LOAD_DISTRIBUTION_LINEAR_IN_Z:
+                    load_parameter = [magnitude_1, magnitude_2, node_1, node_2]
+            comment (str, optional): Comments
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         '''
         # Client model | Solid Load
         clientObject = model.clientModel.factory.create('ns0:solid_load')
@@ -172,13 +206,23 @@ class SolidLoad():
                params: dict = None,
                model = Model):
         '''
-        load_parameter:
-            LOAD_DISTRIBUTION_UNIFORM: load_parameter = [strain_uniform_magnitude_x, strain_uniform_magnitude_y, strain_uniform_magnitude_z]
-            LOAD_DISTRIBUTION_LINEAR_IN_X: load_parameter = [strain_magnitude_x1, strain_magnitude_y1, strain_magnitude_z1, strain_magnitude_x2, strain_magnitude_y2, strain_magnitude_z2, node_1, node_2]
-            LOAD_DISTRIBUTION_LINEAR_IN_Y: load_parameter = [strain_magnitude_x1, strain_magnitude_y1, strain_magnitude_z1, strain_magnitude_x2, strain_magnitude_y2, strain_magnitude_z2, node_1, node_2]
-            LOAD_DISTRIBUTION_LINEAR_IN_Z: load_parameter = [strain_magnitude_x1, strain_magnitude_y1, strain_magnitude_z1, strain_magnitude_x2, strain_magnitude_y2, strain_magnitude_z2, node_1, node_2]
-        params:
-            {''}
+        Args:
+            no (int): Load Tag
+            load_case_no (int): Assigned Load Case
+            solids_no (str): Assigned Solids
+            load_distribution (enum): Solid Load Distribution Enumeration
+            load_parameter (list): Load Parameter List
+                for load_distribution == SolidLoadDistribution.LOAD_DISTRIBUTION_UNIFORM:
+                    load_parameter = [strain_uniform_magnitude_x, strain_uniform_magnitude_y, strain_uniform_magnitude_z]
+                for load_distribution == SolidLoadDistribution.LOAD_DISTRIBUTION_LINEAR_IN_X:
+                    load_parameter = [strain_magnitude_x1, strain_magnitude_y1, strain_magnitude_z1, strain_magnitude_x2, strain_magnitude_y2, strain_magnitude_z2, node_1, node_2]
+                for load_distribution == SolidLoadDistribution.LOAD_DISTRIBUTION_LINEAR_IN_Y:
+                    load_parameter = [strain_magnitude_x1, strain_magnitude_y1, strain_magnitude_z1, strain_magnitude_x2, strain_magnitude_y2, strain_magnitude_z2, node_1, node_2]
+                for load_distribution == SolidLoadDistribution.LOAD_DISTRIBUTION_LINEAR_IN_Z:
+                    load_parameter = [strain_magnitude_x1, strain_magnitude_y1, strain_magnitude_z1, strain_magnitude_x2, strain_magnitude_y2, strain_magnitude_z2, node_1, node_2]
+            comment (str, optional): Comments
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         '''
         # Client model | Solid Load
         clientObject = model.clientModel.factory.create('ns0:solid_load')
@@ -236,10 +280,15 @@ class SolidLoad():
                params: dict = None,
                model = Model):
         '''
-        load_parameter:
-            load_parameter = [angular_velocity, angular_acceleration, axis_definition_p1_x, axis_definition_p1_y, axis_definition_p1_z, axis_definition_p2_x, axis_definition_p2_y, axis_definition_p2_z]
-        params:
-            {''}
+        Args:
+            no (int): Load Tag
+            load_case_no (int): Assigned Load Case
+            solids_no (str): Assigned Solids
+            load_parameter: Load Parameter List
+                load_parameter = [angular_velocity, angular_acceleration, axis_definition_p1_x, axis_definition_p1_y, axis_definition_p1_z, axis_definition_p2_x, axis_definition_p2_y, axis_definition_p2_z]
+            comment (str, optional): Comments
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         '''
         # Client model | Solid Load
         clientObject = model.clientModel.factory.create('ns0:solid_load')
