@@ -20,6 +20,15 @@ class LineHinge():
         """
         assigned_to doesn't work. Can't figure why.
         Assignment in surfaces also doesn't work (surface.has_line_hinges = True).
+
+        Args:
+            no (int): Line Hinge Tag
+            assigned_to (str): Assigned to
+            translational_release (list): Translation Release List
+            rotational_release_phi (int): Rotational Release phi
+            comment (str, optional): Comments
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         """
 
         # Client model | Line Hinge
