@@ -8,14 +8,14 @@ class ConcreteDurability():
                 members_no: str = "1",
                 member_sets_no: str = "1",
                 surfaces_no: str = "1",
-                exposure_classes_reinforcement = [True, False, False, False],
+                exposure_classes_reinforcement: list = [True, False, False, False],
                 exposure_classes_reinforcement_types: list = None,
-                exposure_classes_concrete = [False, False, False],
+                exposure_classes_concrete: list = [False, False, False],
                 exposure_classes_concrete_types: list = None,
-                structural_class = [DurabilityStructuralClassType.STANDARD, False, False, False, False],
-                stainless_steel_reduction = [False],
-                additional_protection_reduction = [False],
-                allowance_deviation = [DurabilityAllowanceDeviationType.STANDARD, False],
+                structural_class: list = [DurabilityStructuralClassType.STANDARD, False, False, False, False],
+                stainless_steel_reduction: list = [False],
+                additional_protection_reduction: list = [False],
+                allowance_deviation: list = [DurabilityAllowanceDeviationType.STANDARD, False],
                 comment: str = '',
                 params: dict = None,
                 model = Model):
@@ -27,15 +27,16 @@ class ConcreteDurability():
             member_sets_no (str): Assigned Member Sets
             surfaces_no (str): Assigned Surfaces
             exposure_classes_reinforcement (list): Exposure Classes Reinforcement Parameters
-            exposure_classes_reinforcement_types (list): Exposure Classes Reinforcement Parameters
+            exposure_classes_reinforcement_types (list of enum): Exposure Classes Reinforcement Type List of Enumeration
             exposure_classes_concrete (list): Exposure Classes Concrete Parameters
-            exposure_classes_concrete_types (list): Exposure Classes Concrete Parameters
+            exposure_classes_concrete_types (list of enum): Exposure Classes Concrete Type List of Enumeration
             structural_class (list): Structural Class Parameters
             stainless_steel_reduction (list): Stainless Steel Reduction Parameters
             additional_protection_reduction (list): Additional Protection Reduction
             allowance_deviation (list): Allowance Deviation Parameters
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+            model (RFEM Class, optional): Model to be edited
         """
 
         # Client model | Concrete Durabilities
